@@ -558,6 +558,7 @@ void mca_btl_openib_endpoint_cpc_complete(mca_btl_openib_endpoint_t *endpoint)
 {
     /* If the CPC uses the CTS protocol, then start it up */
     if (endpoint->endpoint_local_cpc->cbm_uses_cts) {
+        int transport_type_ib_p = 0;
         /* Post our receives, which will make credit management happy
            (i.e., rd_credits will be 0) */
         if (OMPI_SUCCESS != mca_btl_openib_endpoint_post_recvs(endpoint)) {
@@ -573,14 +574,15 @@ void mca_btl_openib_endpoint_cpc_complete(mca_btl_openib_endpoint_t *endpoint)
            receives this side's CTS).  Also send the CTS if we already
            received the peer's CTS (e.g., if this process was slow to
            call cpc_complete(). */
+#if defined(HAVE_STRUCT_IBV_DEVICE_TRANSPORT_TYPE)
+        transport_type_ib_p = (IBV_TRANSPORT_IB == endpoint->endpoint_btl->device->ib_dev->transport_type);
+#endif
         OPAL_OUTPUT((-1, "cpc_complete to peer %s: is IB %d, initiatior %d, cts received: %d",
                      endpoint->endpoint_proc->proc_ompi->proc_hostname,
-                     (IBV_TRANSPORT_IB == 
-                      endpoint->endpoint_btl->device->ib_dev->transport_type),
+                     transport_type_ib_p,
                      endpoint->endpoint_initiator,
                      endpoint->endpoint_cts_received));
-        if (IBV_TRANSPORT_IB == 
-            endpoint->endpoint_btl->device->ib_dev->transport_type ||
+        if (transport_type_ib_p ||
             endpoint->endpoint_initiator ||
             endpoint->endpoint_cts_received) {
             mca_btl_openib_endpoint_send_cts(endpoint);
@@ -650,6 +652,23 @@ void mca_btl_openib_endpoint_connected(mca_btl_openib_endpoint_t *endpoint)
        event trigger. */
     opal_progress_event_users_decrement();
 
+    if(MCA_BTL_XRC_ENABLED) {
+        while(master && !opal_list_is_empty(&endpoint->ib_addr->pending_ep)) {
+            ep_item = opal_list_remove_first(&endpoint->ib_addr->pending_ep);
+            ep = (mca_btl_openib_endpoint_t *)ep_item;
+            if (OMPI_SUCCESS != 
+                ompi_btl_openib_connect_base_start(endpoint->endpoint_local_cpc, 
+                                                   ep)) {
+                BTL_ERROR(("Failed to connect pending endpoint\n"));
+            }
+        }
+        OPAL_THREAD_UNLOCK(&endpoint->ib_addr->addr_lock);
+    }
+
+
+    OPAL_THREAD_UNLOCK(&endpoint->endpoint_lock);
+    /* Process pending packet on the endpoint */
+
     /* While there are frags in the list, process them */
     while (!opal_list_is_empty(&(endpoint->pending_lazy_frags))) {
         frag_item = opal_list_remove_first(&(endpoint->pending_lazy_frags));
@@ -664,19 +683,6 @@ void mca_btl_openib_endpoint_connected(mca_btl_openib_endpoint_t *endpoint)
      * state then we restart them here */
     mca_btl_openib_frag_progress_pending_put_get(endpoint,
             mca_btl_openib_component.rdma_qp);
-
-    if(MCA_BTL_XRC_ENABLED) {
-        while(master && !opal_list_is_empty(&endpoint->ib_addr->pending_ep)) {
-            ep_item = opal_list_remove_first(&endpoint->ib_addr->pending_ep);
-            ep = (mca_btl_openib_endpoint_t *)ep_item;
-            if (OMPI_SUCCESS != 
-                ompi_btl_openib_connect_base_start(endpoint->endpoint_local_cpc, 
-                                                   ep)) {
-                BTL_ERROR(("Failed to connect pending endpoint\n"));
-            }
-        }
-        OPAL_THREAD_UNLOCK(&endpoint->ib_addr->addr_lock);
-    }
 }
 
 /*
