@@ -307,6 +307,9 @@ typedef long long bool;
  * Maximum size of a filename path.
  */
 #include <limits.h>
+#ifdef HAVE_SYS_PARAM_H
+#include <sys/param.h>
+#endif
 #if defined(PATH_MAX)
 #define OMPI_PATH_MAX	(PATH_MAX + 1)
 #elif defined(_POSIX_PATH_MAX)
@@ -499,6 +502,7 @@ static inline uint16_t ntohs(uint16_t netvar) { return netvar; }
 #define sin6_len sin_len
 #define sin6_family sin_family
 #define sin6_port sin_port
+#define sin6_addr sin_addr
 #endif
 
 #if !HAVE_DECL_AF_UNSPEC
@@ -556,4 +560,13 @@ static inline uint16_t ntohs(uint16_t netvar) { return netvar; }
 
 #endif
 
+/* If we're in C++, then just undefine restrict and then define it to
+   nothing.  "restrict" is not part of the C++ language, and we don't
+   have a corresponding AC_CXX_RESTRICT to figure out what the C++
+   compiler supports. */
+#if defined(c_plusplus) || defined(__cplusplus)
+#undef restrict
+#define restrict
+#endif
+
 #endif /* OMPI_BUILDING */
