@@ -12,7 +12,7 @@
  * Copyright (c) 2006-2007 Cisco Systems, Inc.  All rights reserved.
  * Copyright (c) 2007      Los Alamos National Security, LLC.  All rights
  *                         reserved. 
- * Copyright (c) 2008      Sun Microsystems, Inc.  All rights reserved.
+ * Copyright (c) 2008-2009 Sun Microsystems, Inc.  All rights reserved.
  * $COPYRIGHT$
  *
  * Additional copyrights may follow
@@ -617,7 +617,12 @@ static int setup_launch(int *argcptr, char ***argvptr,
         !orte_debug_flag &&
         !orte_debug_daemons_flag &&
         !orte_debug_daemons_file_flag &&
-        !orte_leave_session_attached) {
+        !orte_leave_session_attached &&
+        /* Daemonize when not using qrsh.  Or, if using qrsh, only
+         * daemonize if told to by user with daemonize_qrsh flag. */
+        ((0 != (strcmp("qrsh", mca_plm_rsh_component.agent_param))) ||
+        ((0 == (strcmp("qrsh", mca_plm_rsh_component.agent_param))) &&
+         mca_plm_rsh_component.daemonize_qrsh))) {
         opal_argv_append(&argc, &argv, "--daemonize");
     }
     
@@ -1451,7 +1456,17 @@ static orte_plm_rsh_shell_t find_shell(char *shell)
     int i         = 0;
     char *sh_name = NULL;
 
+    if( (NULL == shell) || (strlen(shell) == 1) ) {
+        /* Malformed shell */
+        return ORTE_PLM_RSH_SHELL_UNKNOWN;
+    }
+
     sh_name = rindex(shell, '/');
+    if( NULL == sh_name ) {
+        /* Malformed shell */
+        return ORTE_PLM_RSH_SHELL_UNKNOWN;
+    }
+
     /* skip the '/' */
     ++sh_name;
     for (i = 0; i < (int)(sizeof (orte_plm_rsh_shell_name) /
